1.0.0
-----

* Repackage to hatch/pyproject.toml
* Migrate to smbus2

0.1.0
-----

* Port to new i2cdevice API
* Breaking change from singleton module to AS7262 class

0.0.2
-----

* Extended reset delay to avoid IO Errors

0.0.1
-----

* Initial Release
